@@ -510,7 +510,7 @@ class AiService:
                 launch_mode = params['launchMode']
             else:
                 launch_mode = 'automatic'
-            if 'engine' in params['engine']:
+            if 'engine' in params:
                 engine = params['engine']
             else:
                 engine = 'aws-sklearn-serverless'
